runAppWithErrorHandling static method

void runAppWithErrorHandling(
  1. Widget app, {
  2. List<NavigatorObserver>? navigatorObservers,
})

Run the app in a Zone that catches errors. This is a simpler version of setupErrorHandling that doesn't create a new zone if we're already in one.

Implementation

static void runAppWithErrorHandling(
  Widget app, {
  List<NavigatorObserver>? navigatorObservers,
}) {
  final handler = HummErrorHandler();

  // Set up Flutter error handling
  handler.setupFlutterErrorHandling();

  // Just run the app - we'll let the caller decide if they want to use runZonedGuarded
  runApp(app);
}